@@ -10,6 +10,7 @@ from datalad.tests.utils import (
     assert_raises,
     assert_repo_status,
     assert_result_count,
+    assert_status,
     known_failure_windows,
     serve_path_via_http,
     skip_if_adjusted_branch,
@@ -48,6 +49,20 @@ def test_initremote(store_path, store_url, ds_path):
     url = "ria+" + store_url
     init_opts = common_init_opts + ['url={}'.format(url)]
 
+    # fail when there's no RIA store at the destination
+    assert_raises(CommandError, ds.repo.init_remote, 'ora-remote',
+                  options=init_opts)
+    # Doesn't actually create a remote if it fails
+    assert_not_in('ora-remote',
+                  [cfg['name']
+                   for uuid, cfg in ds.repo.get_special_remotes().items()]
+                  )
+
+    # now make it a store
+    io = LocalIO()
+    create_store(io, store_path, '1')
+    create_ds_in_store(io, store_path, ds.id, '2', '1')
+
     # fails on non-RIA URL
     assert_raises(CommandError, ds.repo.init_remote, 'ora-remote',
                   options=common_init_opts + ['url={}'
@@ -100,11 +115,23 @@ def test_read_access(store_path, store_url, ds_path):
     create_store(io, store_path, '1')
     create_ds_in_store(io, store_path, ds.id, '2', '1')
     ds.repo.init_remote('ora-remote', options=init_opts)
-    ds.repo.fsck(remote='ora-remote', fast=True)
+    fsck_results = ds.repo.fsck(remote='ora-remote', fast=True)
+    # Note: Failures in the special remote will show up as a success=False
+    # result for fsck -> the call itself would not fail.
+    for r in fsck_results:
+        if "note" in r:
+            # we could simply assert "note" to not be in r, but we want proper
+            # error reporting - content of note, not just its unexpected
+            # existence.
+            assert_equal(r["success"], "true",
+                         msg="git-annex-fsck failed with ORA over HTTP: %s" % r)
+        assert_equal(r["error-messages"], [])
     store_uuid = ds.siblings(name='ora-remote',
-                             return_type='item-or-list')['annex-uuid']
+                             return_type='item-or-list',
+                             result_renderer='disabled')['annex-uuid']
     here_uuid = ds.siblings(name='here',
-                            return_type='item-or-list')['annex-uuid']
+                            return_type='item-or-list',
+                            result_renderer='disabled')['annex-uuid']
 
     # nothing in store yet:
     for f in files:
@@ -131,3 +158,8 @@ def test_read_access(store_path, store_url, ds_path):
     assert_result_count(res, 2, status='ok', type='file', action='get',
                         message="from ora-remote...")
 
+    # try whether the reported access URL is correct
+    one_url = ds.repo.whereis('one.txt', output='full'
+        )[store_uuid]['urls'].pop()
+    assert_status('ok', ds.download_url(urls=[one_url], path=str(ds.pathobj / 'dummy')))
+
